@@ -17,16 +17,22 @@ import Types
 modifyOptions :: Options -> IO Options
 modifyOptions opts = found ||> notFound
   where
-    found = addPath opts <$> findCabalDev
+    found = addPath opts <$> findCabalDev (sandbox opts)
     notFound = return opts
 
-findCabalDev :: IO String
-findCabalDev = getCurrentDirectory >>= searchIt . splitPath
+findCabalDev :: Maybe String -> IO FilePath
+findCabalDev (Just path) = do
+    exist <- doesDirectoryExist path
+    if exist then
+        findConf path
+      else
+        findCabalDev Nothing
+findCabalDev Nothing = getCurrentDirectory >>= searchIt . splitPath
 
 addPath :: Options -> String -> Options
 addPath orig_opts path = do
     let orig_ghcopt = ghcOpts orig_opts
-    orig_opts { ghcOpts = orig_ghcopt ++ ["-package-conf", path] }
+    orig_opts { ghcOpts = orig_ghcopt ++ ["-package-conf", path, "-no-user-package-conf"] }
 
 searchIt :: [FilePath] -> IO FilePath
 searchIt [] = throwIO $ userError "Not found"
