@@ -6,14 +6,14 @@ import CoreMonad
 import ErrMsg
 import Exception
 import GHC
+import GHCApi
 import Prelude hiding (catch)
 import Types
 
 ----------------------------------------------------------------
 
 checkSyntax :: Options -> String -> IO String
-checkSyntax opt file = do
-  unlines <$> check opt file
+checkSyntax opt file = unlines <$> check opt file
 
 ----------------------------------------------------------------
 
@@ -25,4 +25,6 @@ check opt fileName = withGHC $ checkIt `gcatch` handleErrMsg
         setTargetFile file
         load LoadAllTargets
         liftIO readLog
-    options = ["-Wall","-fno-warn-unused-do-bind"] ++ ghcOpts opt
+    options
+      | expandSplice opt = ["-w:"] ++ ghcOpts opt
+      | otherwise        = ["-Wall","-fno-warn-unused-do-bind"] ++ ghcOpts opt
